@@ -1,20 +1,23 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """
 Example showing how the BME280 library can be used to set the various
 parameters supported by the sensor.
 Refer to the BME280 datasheet to understand what these parameters do
 """
 import time
-
 import board
-import busio
 import adafruit_bme280
 
-# Create library object using our Bus I2C port
-i2c = busio.I2C(board.SCL, board.SDA)
+# Create sensor object, using the board's default I2C bus.
+i2c = board.I2C()  # uses board.SCL and board.SDA
 bme280 = adafruit_bme280.Adafruit_BME280_I2C(i2c)
 
-# OR create library object using our Bus SPI port
-# spi = busio.SPI(board.SCK, board.MOSI, board.MISO)
+# OR create sensor object, using the board's default SPI bus.
+# SPI setup
+# from digitalio import DigitalInOut
+# spi = board.SPI()
 # bme_cs = digitalio.DigitalInOut(board.D10)
 # bme280 = adafruit_bme280.Adafruit_BME280_SPI(spi, bme_cs)
 
